@@ -123,6 +123,7 @@ class TestITListener(object):
 
         for item in items:
             if hasattr(item.function, 'test_external_id'):
+
                 if item.own_markers:
                     for mark in item.own_markers:
                         if mark.name == 'parametrize':
@@ -292,6 +293,7 @@ class TestITListener(object):
                     data_item['traces'],
                     data_item['attachments'],
                     data_item['parameters'],
+                    data_item['properties'],
                     data_item['resultLinks'],
                     data_item['duration'],
                     data_item['failureReasonName'],
@@ -378,8 +380,17 @@ class TestITListener(object):
 
     @staticmethod
     def _get_parameters_from(item):
-        if hasattr(item, 'test_parameters'):
-            return item.test_parameters
+        if hasattr(item, 'array_parametrize_mark_id'):
+            test_parameters = {}
+            for key, parameter in item.callspec.params.items():
+                test_parameters[key] = str(parameter)
+            return test_parameters
+        return None
+
+    @staticmethod
+    def _get_properties_from(item):
+        if hasattr(item, 'test_properties'):
+            return item.test_properties
         return None
 
     @staticmethod
@@ -497,6 +508,7 @@ class TestITListener(object):
             'namespace': item.function.__module__,
             'attachments': TestITListener._get_attachments_from(item),
             'parameters': TestITListener._get_parameters_from(item),
+            'properties': TestITListener._get_properties_from(item),
             'classname': TestITListener._get_classname_from(item),
             'title': TestITListener._get_title_from(item),
             'description': TestITListener._get_description_from(item),
@@ -627,20 +639,25 @@ class TestITListener(object):
         attachments = []
         for path in attach_paths:
             if os.path.isfile(path):
-                attachments.append(
-                    {
-                        'id': self.requests.load_attachment(open(path, "rb"))
-                    })
+                attachment_id = self.requests.load_attachment(open(path, "rb"))
+
+                if attachment_id:
+                    attachments.append(
+                        {
+                            'id': attachment_id
+                        })
             else:
                 print(f'File ({path}) not found!')
         return attachments
 
     @testit_adapter_pytest.hookimpl
-    def add_parameters(self, parameters):
-        if self.item and not hasattr(self.item, 'test_parameters'):
-            self.item.test_parameters = {}
-            for key, parameter in parameters.items():
-                self.item.test_parameters[key] = str(parameter)
+    def add_properties(self, properties):
+        if self.item and not hasattr(self.item, 'test_properties'):
+            self.item.test_properties = {}
+            for key, property in properties.items():
+                if hasattr(self.item,
+                           'callspec') and key not in self.item.callspec.params:
+                    self.item.test_properties[key] = str(property)
 
     @testit_adapter_pytest.hookimpl
     def get_pytest_check_outcome(self):
